@@ -25,8 +25,6 @@ class VAE(nn.Module):
     def __init__(self, in_dim, z_dim):
         super(VAE, self).__init__()
 
-        self.in_dim = in_dim
-
         # Encoder
         self.mu_enc = nn.Linear(in_dim, z_dim)
         self.logvar_enc = nn.Linear(in_dim, z_dim)
@@ -37,7 +35,7 @@ class VAE(nn.Module):
 
     def encode(self, x):
         # Standardization
-        x = nn.BatchNorm1d(self.in_dim)(x)
+        x = nn.BatchNorm1d(self.mu_enc.in_features)(x)
 
         mu = self.mu_enc(x)
         std = self.logvar_enc(x).exp().pow(0.5)
